import axios from "axios"
type AvatarData = any

interface UsePostAvatarItemListParams {
  onPostSuccess: (data: AvatarData) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

axios.defaults.withCredentials = true;

export const UsePostAvatarItemList = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostAvatarItemListParams) => {
  const postAvatarData = (avatarData: AvatarData) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/updateAvatarCustomization`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postAvatarData }
}

type KeychipCreation = any

interface UsePostNewKeychipParams {
  onPostSuccess: (data: KeychipCreation) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostNewKeychip = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostNewKeychipParams) => {
  
  const createNewKeychip = (postTeamData: KeychipCreation) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/create_keychip`

    axios
      .post(apiUrl, postTeamData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { createNewKeychip }
}
type MapIcon = any

interface UsePostMapIconParams {
  onPostSuccess: (data: MapIcon) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostMapIcon = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostMapIconParams) => {
  
  const postMapIcon = (avatarData: MapIcon) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_item_mapchar`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postMapIcon }
}

type NameplateId = any

interface UsePostNameplateIdParams {
  onPostSuccess: (data: NameplateId) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostNamePlate = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostNameplateIdParams) => {
  
  const postNamePlate = (avatarData: NameplateId) => {
    setLoading(true)

    const source = axios.CancelToken.source()

    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_nameplateId`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postNamePlate }
}
type PlayerTeam = any

interface UsePostPlayerTeamParams {
  onPostSuccess: (data: PlayerTeam) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostPlayerTeam = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostPlayerTeamParams) => {
  
  const postTeamName = (PostTeamData: PlayerTeam) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_player_team`

    axios
      .post(apiUrl, PostTeamData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postTeamName }
}

type PlayerTeamProfile = any

interface UsePostPlayerTeamProfileParams {
  onPostSuccess: (data: PlayerTeamProfile) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostPlayerTeamProfile = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostPlayerTeamProfileParams) => {
  
  const postTeamNameProfile = (
    postPlayerTeamProfileData: PlayerTeamProfile,
  ) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_profile_player_team`

    axios
      .post(apiUrl, postPlayerTeamProfileData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postTeamNameProfile }
}

type SystemVoice = any

interface UsePostSystemVoiceParams {
  onPostSuccess: (data: SystemVoice) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostSystemVoice = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostSystemVoiceParams) => {
  
  const postVoiceID = (avatarData: SystemVoice) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_item_duel`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postVoiceID }
}

type TrophyName = { trophyId: number }

interface UsePostTrophyParams {
  onPostSuccess: (data: TrophyName) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostTrophy = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostTrophyParams) => {
  
  const postTrophy = (avatarData: TrophyName) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_trophyid`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postTrophy }
}
type playerRivals = any

interface UsePostPlayerRivalParams {
  onPostSuccess: (data: playerRivals) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostPlayerRival = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostPlayerRivalParams) => {
  
  const postRival = (avatarData: playerRivals) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_player_rivals`

    axios
      .post(apiUrl, avatarData, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postRival }
}

type playerFavoriteSongs = any

interface UsePostPlayerFavoriteSongsParams {
  onPostSuccess: (data: playerFavoriteSongs) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostFavoriteSongs = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostPlayerFavoriteSongsParams) => {
  const postFavoriteSong = (FavoriteSong: playerFavoriteSongs) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/update_chuni_favorite_music`;

    axios
      .post(apiUrl, FavoriteSong, {
        cancelToken: source.token,
      })
      .then((response) => {
        if (response.status !== 200) {
          throw new Error("Network response was not ok")
        }
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postFavoriteSong }
}

type NewPlayerCard = any

interface UsePostNewAccessCodeParam {
  onPostSuccess: (data: NewPlayerCard) => void
  setLoading: (loading: boolean) => void
  setError: (error: string | null) => void
}

export const UsePostNewCard = ({
  onPostSuccess,
  setLoading,
  setError,
}: UsePostNewAccessCodeParam) => {
  
  const postAccessCode = (accesscodeData: NewPlayerCard) => {
    setLoading(true)

    const source = axios.CancelToken.source()
    // Include the user ID in the request URL
    const apiUrl = `${process.env.NEXT_PUBLIC_ARTEMIS_API_URL}/SDHD/updateAccessCode`

    axios
      .post(
        apiUrl,
        { access_code: accesscodeData.access_code },
        { cancelToken: source.token },
      )
      .then((response) => {
        onPostSuccess(response.data)
        setLoading(false)
      })
      .catch((error) => {
        if (axios.isCancel(error)) {
          console.log(error.message)
        } else {
          setError(error.message)
          setLoading(false)
        }
      })

    return () => {
      source.cancel("Operation canceled by the user.")
    }
  }

  return { postAccessCode }
}
