"use client"
import React, { createContext, useContext, useState, ReactNode } from "react"

interface SettingsContextProps {
  isAverageEnabled: boolean
  isBestPossibleEnabled: boolean // Added line
  toggleAverage: () => void
  toggleBestPossible: () => void // Added line
}

const SettingsContext = createContext<SettingsContextProps | undefined>(
  undefined,
)

interface SettingsProviderProps {
  children: ReactNode
}

export const SettingsProvider: React.FC<SettingsProviderProps> = ({
  children,
}) => {
  const [isAverageEnabled, setTextEnabled] = useState(false)
  const [isBestPossibleEnabled, setBestPossibleEnabled] = useState(false)

  const toggleAverage = () => {
    setTextEnabled((prev) => !prev)
  }

  const toggleBestPossible = () => {
    setBestPossibleEnabled((prev) => !prev)
  }

  return (
    <SettingsContext.Provider
      value={{
        isAverageEnabled,
        isBestPossibleEnabled,
        toggleAverage,
        toggleBestPossible,
      }}
    >
      {children}
    </SettingsContext.Provider>
  )
}

export const useSettings = () => {
  const context = useContext(SettingsContext)
  if (!context) {
    throw new Error("useSettings must be used within a SettingsProvider")
  }
  return context
}
