import type { Metadata } from "next"
import { Inter } from "next/font/google"
import "./globals.css"
import { ClientCookiesProvider } from "@/components/shared/cookieProvider/Page"
import { cookies } from "next/headers"
const inter = Inter({ subsets: ["latin"] })
import { SettingsProvider } from "./context/SettingsContext"
import { ThemeProvider } from "@/components/theme-provider"
export const metadata: Metadata = {
  title: "Cozy Net",
  description: "A Cozy ALL.net Emulation Frontend",
}

export default function RootLayout({
  children,
}: {
  children: React.ReactNode
}) {
  return (
    <html lang="en">
      <body className={inter.className}>
        <ThemeProvider
          attribute="class"
          defaultTheme="system"
          enableSystem
          themes={["gruvbox", "light", "dark", "mocha"]}
          disableTransitionOnChange
        >
          <SettingsProvider>
            <ClientCookiesProvider value={cookies().getAll()}>
              {children}
            </ClientCookiesProvider>
          </SettingsProvider>
        </ThemeProvider>
      </body>
    </html>
  )
}
