/* eslint-disable @next/next/no-img-element */

"use client"
import { useState } from "react"
import { UsePlayerAvatarItems, UsePlayerInfo } from "@/app/axios/useFetchApi"
import { UsePostAvatarItemList } from "@/app/axios/usePostApi"
type PlayerData = {
  avatarBack: string
  avatarItem: string
  avatarWear: string
  avatarFront: string
  avatarSkin: string
  avatarHead: string
  avatar_skinfoot_l: string
  avatar_skinfoot_r: string
  avatarFace: string
}

type AvatarParts = Record<string, string>

type DropdownOption = {
  label: string
  value: string
  category: string
  sortName: string
}

type DropdownProps = {
  options: DropdownOption[]
  onChange: (value: string) => void
  label: string
  value: string
}

const Dropdown: React.FC<DropdownProps & { className?: string }> = ({
  options,
  onChange,
  label,
  value,
  className,
}) => {
  return (
    <div className={`dropdown-container relative ${className}`}>
      <label className="block text-sm font-medium text-typography pb-1 pt-2  ">
        {label}
      </label>
      <div className="mt-1 relative">
        <select
          value={value}
          onChange={(e) => onChange(e.target.value)}
          className=" w-[230px] sm:w-[280px] md:w-[280px] lg:w-[280px] text-typography px-3 py-2 border border-transparent font-medium rounded-sm bg-background  focus:outline-none transition duration-150 ease-in-out whitespace-nowrap"
        >
          {options.map((option, index) => (
            <option
              key={`${option.value}-${index}`}
              value={option.value}
              className="text-gray-900"
            >
              {option.label}
            </option>
          ))}
        </select>
      </div>
    </div>
  )
}

const AvatarCustomizationData: React.FC = () => {
  const [avatarCustomizationData, setPlayerInfo] = useState<PlayerData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [avatarItems, setAvatarItems] = useState<PlayerData[]>([])

  UsePlayerAvatarItems({
    setPlayerAvatarItems: setAvatarItems,
    setLoading,
    setError,
  })

  UsePlayerInfo({ setPlayerInfo, setLoading, setError })

  const { postAvatarData } = UsePostAvatarItemList({
    onPostSuccess: (data) => {
      console.log("Data posted successfully:", data)
    },
    setLoading,
    setError,
  })

  const getAvatarParts = (playerData: PlayerData): AvatarParts => ({
    avatar_back: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarBack}.png`,
    avatar_face_static: `${process.env.NEXT_PUBLIC_CDN}avatarStatic/CHU_UI_Avatar_Tex_Face.png`,
    avatar_face: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarFace}.png`,
    avatar_item_r: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarItem}.png`,
    avatar_item_l: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarItem}.png`,
    avatar_wear: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarWear}.png`,
    avatar_Front: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarFront}.png`,
    avatar_skin: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarSkin}.png`,
    avatar_head: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarHead}.png`,
    avatar_skinfoot_l: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarSkin}.png`,
    avatar_skinfoot_r: `${process.env.NEXT_PUBLIC_CDN}avatarAccessory/CHU_UI_Avatar_Tex_0${playerData.avatarSkin}.png`,
    avatar_hand_r: `${process.env.NEXT_PUBLIC_CDN}avatarStatic/CHU_UI_Avatar_Tex_RightHand.png`,
    avatar_hand_l: `${process.env.NEXT_PUBLIC_CDN}avatarStatic/CHU_UI_Avatar_Tex_LeftHand.png`,
  })

  const handleSelectionChange = (part: keyof PlayerData, value: string) => {
    console.log(`Setting ${part} to ${value}`)
    setPlayerInfo(
      avatarCustomizationData.map((data, index) =>
        index === 0 ? { ...data, [part]: value } : data,
      ),
    )
  }

  const handlePostData = () => {
    if (avatarCustomizationData.length > 0) {
      const { avatarItem, avatarBack, avatarFace, avatarWear, avatarHead } =
        avatarCustomizationData[0]

      const dataToPost = {
        avatarItem,
        avatarBack,
        avatarFace,
        avatarWear,
        avatarHead,
      }

      postAvatarData(dataToPost)
      console.log("Attempting to post data", dataToPost)
    }
  }

  if (loading) return <div></div>
  if (error) return <div>Error: {error}</div>
  if (
    !Array.isArray(avatarCustomizationData) ||
    avatarCustomizationData.length === 0
  ) {
    return <div>No player data found.</div>
  }

  const playerCustomization = getAvatarParts(avatarCustomizationData[0])

  const dropdownOptions: DropdownOption[] = avatarItems.map((item: any) => ({
    label: item.str,
    value: item.item_id.toString(), // Use item_id as the value
    category: item.category,
    sortName: item.sortName,
  }))

  const avatarHeadOptions = dropdownOptions.filter(
    (option) => option.category === "2",
  )
  const avatarFaceCoverOptions = dropdownOptions.filter(
    (option) => option.category === "3",
  )
  const avatarItemOptions = dropdownOptions.filter(
    (option) => option.category === "5",
  )
  const avatarBackOptions = dropdownOptions.filter(
    (option) => option.category === "7",
  )
  const avatarWearOptions = dropdownOptions.filter(
    (option) => option.category === "1",
  )

  return (
    <div className="bg-subsectionbackgroundcolor rounded-sm  mx-auto">
      <div className="flex flex-col md:flex-row justify-center items-center">
        <div className="avatar_group w-full md:w-1/2 flex justify-center items-center">
          <div className="avatar_base">
            {Object.entries(playerCustomization).map(([className, src]) => (
              <div className={className} key={className}>
                <img src={src} alt={className} />
              </div>
            ))}
          </div>
        </div>

        <div className="avatar_customization_dropdowns w-full md:w-1/2 flex flex-col justify-center items-center">
          <Dropdown
            options={avatarHeadOptions}
            onChange={(value) => handleSelectionChange("avatarHead", value)}
            label="Head Options: "
            value={avatarCustomizationData[0].avatarHead}
          />

          <Dropdown
            options={avatarFaceCoverOptions}
            onChange={(value) => handleSelectionChange("avatarFace", value)}
            label="Face Cover Options: "
            value={avatarCustomizationData[0].avatarFace}
          />

          <Dropdown
            options={avatarItemOptions}
            onChange={(value) => handleSelectionChange("avatarItem", value)}
            label="Item Options: "
            value={avatarCustomizationData[0].avatarItem}
          />

          <Dropdown
            options={avatarBackOptions}
            onChange={(value) => handleSelectionChange("avatarBack", value)}
            label="Back Options: "
            value={avatarCustomizationData[0].avatarBack}
          />

          <Dropdown
            options={avatarWearOptions}
            onChange={(value) => handleSelectionChange("avatarWear", value)}
            label="Outfit Options: "
            value={avatarCustomizationData[0].avatarWear}
          />
          <div className="pt-4">
            <button
              onClick={handlePostData}
              className="text-typography px-3 py-2 mb-3 border border-transparent font-medium rounded-sm bg-buttonbackgroundcolor hover:text-buttontexthovercolor hover:bg-buttonhovercolor focus:outline-none transition duration-150 ease-in-out whitespace-nowrap"
            >
              Update Avatar
            </button>
          </div>
        </div>
      </div>
    </div>
  )
}

export default AvatarCustomizationData
