"use client"
import { useState, ChangeEvent } from "react"
import { UsePostNewCard } from "@/app/axios/usePostApi"
import { Input } from "./ui/input"

const UpdateCard = () => {
  const [newAccessCode, setNewAccessCode] = useState("")
  const [error, setError] = useState("")

  const { postAccessCode } = UsePostNewCard({
    onPostSuccess: (data) => {},
    setLoading: (loading) => {},
    setError: (err) => {
      setError("Failed to update access code. Please try again.")
    },
  })

  const handleUpdateCard = async () => {
    if (!newAccessCode) {
      setError("Please enter a new access code.")
      return
    }

    if (newAccessCode.length !== 20) {
      setError("The access code must have exactly 20 digits.")
      return
    }

    setError("")

    try {
      console.log("Attempting to update access code:", newAccessCode)
      await postAccessCode({ access_code: newAccessCode })

      setNewAccessCode("")
    } catch (error) {}
  }

  const handleGenerateAccessCode = () => {
    const randomCode = Array.from({ length: 20 }, () =>
      Math.floor(Math.random() * 10),
    )
    setNewAccessCode(randomCode.join(""))
  }

  const handleInputChange = (e: ChangeEvent<HTMLInputElement>) => {
    let numericValue = e.target.value.replace(/\D/g, "")

    numericValue = numericValue.slice(0, 20)
    setNewAccessCode(numericValue)
  }

  return (
    <div className="flex items-center justify-center">
      <div className="relative flex w-[390px] flex-col rounded-sm bg-subsectionbackgroundcolor p-2 pb-4">
        <label className="mb-2 block pb-1 pt-1 text-sm font-bold text-typography">
          Change Aime Card - Must be 20 digits long
        </label>
        <div className=" flex-grow">
          <Input
            type="text"
            name="newAccessCode"
            placeholder="New Aime Card"
            value={newAccessCode}
            onChange={handleInputChange}
            maxLength={20}
            className="w-[370px] rounded-md border border-gray-300 p-2 font-mono focus:outline-none focus:ring-2 focus:ring-blue-500"
          />
        </div>
        {error && <p className="px-2 py-1 text-red-500">{error}</p>}
        <div className="mt-2 flex justify-between">
          <div className="flex">
            <button
              onClick={handleGenerateAccessCode}
              className="hover:bg-red mb-3 mr-2 whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium  text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
            >
              Generate Card
            </button>
            <button
              onClick={handleUpdateCard}
              className="hover:bg-red mb-3 whitespace-nowrap  rounded-sm border border-transparent bg-background px-3 py-2 font-medium  text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
            >
              Change Card
            </button>
          </div>
        </div>
      </div>
    </div>
  )
}

export default UpdateCard
