/* eslint-disable @next/next/no-img-element */
"use client"
import React, { useEffect, useState } from "react"
import {
  UsePlayerAvailableMapIcons,
  UsePlayerMapIcon,
} from "@/app/axios/useFetchApi"
import { UsePostMapIcon } from "@/app/axios/usePostApi"
type PlayerData = {
  mapIconId: string
}
type playerMapIcon = {
  itemId: string
  str: string
  imagePath: string
}

type DropdownOption = {
  str: string
  itemId: string
  imagePath: string
}

type DropdownProps = {
  options: DropdownOption[]
  onChange: (value: string) => void
  str: string
  id: string
}

const DEFAULT_IMAGE = `${process.env.NEXT_PUBLIC_CDN}mapIcon/CHU_UI_MapIcon_00000001.png`

const Dropdown: React.FC<DropdownProps & { className?: string }> = ({
  options,
  onChange,
  str,
  id,
  className,
}) => {
  return (
    <div className={`dropdown-container relative ${className}`}>
      <label className="block pb-1 pt-2 text-sm  font-medium text-typography  ">
        {str}
      </label>
      <div className="relative mt-1">
        <select
          value={id}
          onChange={(e) => {
            //    console.log("Dropdown value changed:", e.target.value);
            onChange(e.target.value)
          }}
          className=" w-[230px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium text-typography transition duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
        >
          {options.map((option, index) => (
            <option
              key={`${option.itemId}-${index}`}
              value={option.itemId}
              className=" dark:text-white"
            >
              {option.str}
            </option>
          ))}
        </select>
      </div>
    </div>
  )
}

const PlayerMapIconComponent: React.FC = () => {
  const [playerData, setPlayerData] = useState<PlayerData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [mapIconData, setMapIconData] = useState<playerMapIcon[]>([])
  const [selectedNameplateId, setSelectedItemId] = useState<string>("")
  const [playerInfoLoaded, setPlayerInfoLoaded] = useState(false)

  UsePlayerMapIcon({
    setPlayerMapIcon: setPlayerData,
    setLoading,
    setError,
  })

  UsePlayerAvailableMapIcons({
    setPlayerAvailableMapIcons: setMapIconData,
    setLoading,
    setError,
    onSuccess: (data) => {
      // Handle success if needed
    },
  })

  useEffect(() => {
    if (playerData.length > 0 && !playerInfoLoaded) {
      const initialMapIconId = playerData[0].mapIconId
      setSelectedItemId(initialMapIconId)
      setPlayerInfoLoaded(true)
    }
  }, [playerData, playerInfoLoaded])

  const { postMapIcon } = UsePostMapIcon({
    onPostSuccess: (data) => {
      console.log("Data posted successfully:", data)
    },
    setLoading,
    setError,
  })

  const handleSelectionChange = (part: keyof PlayerData, mapIconId: string) => {
    if (part === "mapIconId") {
      setSelectedItemId(mapIconId)
      console.log("Selected itemId:", mapIconId)
    }
    setPlayerData(
      playerData.map((data, index) =>
        index === 0 ? { ...data, [part]: mapIconId } : data,
      ),
    )
  }

  const handlePostData = () => {
    if (playerData.length > 0) {
      const { mapIconId } = playerData[0]

      const dataToPost = {
        mapIconId: selectedNameplateId,
      }

      postMapIcon(dataToPost)
      console.log("Attempting to post data", dataToPost)
    }
  }

  if (loading) return <div>Loading...</div>
  if (error) return <div>Error: {error}</div>
  if (!Array.isArray(playerData) || playerData.length === 0) {
    return <div>No player data found.</div>
  }

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      {selectedNameplateId && (
        <img
          className="h-[140px] w-[140px]"
          src={`${
            process.env.NEXT_PUBLIC_CDN
          }mapIcon/CHU_UI_MapIcon_${selectedNameplateId
            .toString()
            .padStart(8, "0")}.png`}
          alt="itemID"
          onError={(e) => {
            console.error("Error loading image:", e)
            e.currentTarget.src = DEFAULT_IMAGE
          }}
          onLoad={() => {}}
        />
      )}
      <div className="flex w-full flex-col items-start md:w-auto">
        <Dropdown
          options={mapIconData.map((data) => ({
            itemId: data.itemId,
            str: data.str,
            imagePath: data.imagePath,
          }))}
          onChange={(value) => handleSelectionChange("mapIconId", value)}
          str="Map Icon Options: "
          id={selectedNameplateId}
        />

        <div className="mt-4 flex items-center">
          <button
            onClick={handlePostData}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Update Map Icon
          </button>
        </div>
      </div>
    </div>
  )
}

export default PlayerMapIconComponent
