/* eslint-disable @next/next/no-img-element */

"use client"
import React, { useEffect, useState } from "react"
import { UsePostNamePlate } from "@/app/axios/usePostApi"
import { UsePlayerAvailableNameplates } from "@/app/axios/useFetchApi"
import { UsePlayerNamePlates } from "@/app/axios/useFetchApi"
import { DropdowNameplateProps, DropdownNameplateOption, Nameplate, PlayerNameplateData } from "@/lib/types"

const DEFAULT_IMAGE = `${process.env.NEXT_PUBLIC_CDN}namePlates/CHU_UI_NamePlate_00000001.png`

const Dropdown: React.FC<DropdowNameplateProps & { className?: string }> = ({
  options,
  onChange,
  str,
  id,
  className,
}) => {
  return (
    <div className={`dropdown-container relative ${className}`}>
      <label className="block pb-1 pt-2 text-sm  font-medium text-typography  ">
        {str}
      </label>
      <div className="relative mt-1">
        <select
          value={id}
          onChange={(e) => {

            onChange(e.target.value)
          }}
          className=" w-[230px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium text-typography transition duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
        >
          {options.map((option, index) => (
            <option
              key={`${option.nameplateId}-${index}`}
              value={option.nameplateId}
              className=" dark:text-white"
            >
              {option.str}
            </option>
          ))}
        </select>
      </div>
    </div>
  )
}

const PlayerNamePlateComponent: React.FC = () => {
  const [playerData, setPlayerData] = useState<PlayerNameplateData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [namePlateData, setNamePlateData] = useState<Nameplate[]>([])
  const [selectedNameplateId, setSelectedNameplateId] = useState<string>("")
  const [playerInfoLoaded, setPlayerInfoLoaded] = useState(false)

  UsePlayerNamePlates({
    setPlayerNameplate: setPlayerData,
    setLoading,
    setError,
  })

  UsePlayerAvailableNameplates({
    setPlayerAvailableNameplates: setNamePlateData,
    setLoading,
    setError,
    onSuccess: (data) => {
    },
  })

  useEffect(() => {
    if (playerData.length > 0 && !playerInfoLoaded) {
      const initialNameplateId = playerData[0].nameplateId
      setSelectedNameplateId(initialNameplateId)
      setPlayerInfoLoaded(true)
    }
  }, [playerData, playerInfoLoaded])

  const { postNamePlate } = UsePostNamePlate({
    onPostSuccess: (data) => {
      console.log("Data posted successfully:", data)
    },
    setLoading,
    setError,
  })

  const handleSelectionChange = (
    part: keyof PlayerNameplateData,
    nameplateId: string,
  ) => {
    if (part === "nameplateId") {
      setSelectedNameplateId(nameplateId)
      console.log("Selected nameplateId:", nameplateId)
    }
    setPlayerData(
      playerData.map((data, index) =>
        index === 0 ? { ...data, [part]: nameplateId } : data,
      ),
    )
  }

  const handlePostData = () => {
    if (playerData.length > 0) {
      const dataToPost = {
        nameplateId: selectedNameplateId,
      }

      postNamePlate(dataToPost)
      console.log("Attempting to post data", dataToPost)
    }
  }

  if (loading) return <div>Loading...</div>
  if (error) return <div>Error: {error}</div>
  if (!Array.isArray(playerData) || playerData.length === 0) {
    return <div>No player data found.</div>
  }

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      {selectedNameplateId && (
        <img
          className="w-[300px]"
          src={`${process.env.NEXT_PUBLIC_CDN
            }namePlates/CHU_UI_NamePlate_${selectedNameplateId
              .toString()
              .padStart(8, "0")}.png`}
          alt="Nameplate"
          onError={(e) => {
            console.error("Error loading image:", e)
            e.currentTarget.src = DEFAULT_IMAGE
          }}
          onLoad={() => { }}
        />
      )}
      <div className="flex w-full flex-col items-start md:w-auto">
        <Dropdown
          options={namePlateData.map((data) => ({
            str: data.str,
            nameplateId: data.nameplateId,
            imagePath: data.imagePath,
          }))}
          onChange={(value) => handleSelectionChange("nameplateId", value)}
          str="Nameplate Options: "
          id={selectedNameplateId}
        />

        <div className="mt-4 flex items-center">
          <button
            onClick={handlePostData}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Update Nameplate
          </button>
        </div>
      </div>
    </div>
  )
}

export default PlayerNamePlateComponent
