"use client"

import { zodResolver } from "@hookform/resolvers/zod"
import { useForm } from "react-hook-form"
import * as z from "zod"

import { Button } from "@/components/ui/button"
import {
  Form,
  FormControl,
  FormDescription,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form"
import { Input } from "@/components/ui/input"
import { toast } from "@/components/ui/use-toast"

const FormSchema = z.object({
  password: z.string().min(8, {
    message: "Username must be at least 2 characters.",
  }),
})
export function PasswordResetForm() {
  const form = useForm<z.infer<typeof FormSchema>>({
    resolver: zodResolver(FormSchema),
    defaultValues: {
      password: "",
    },
  })

  function onSubmit(data: z.infer<typeof FormSchema>) {
    toast({
      title: "You submitted the following values:",
      description: (
        <pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(data, null, 2)}</code>
        </pre>
      ),
    })
  }

  return (
    <Form {...form}>
      <form
        onSubmit={form.handleSubmit(onSubmit)}
        className="w-2/3 space-y-4 pl-4"
      >
        <FormField
          control={form.control}
          name="password"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Reset password</FormLabel>
              <FormDescription className="dark:text-text">
                Enter a new password
              </FormDescription>
              <FormControl>
                <Input
                  placeholder="New Password..."
                  value={field.value.replace(/./g, "*")} // Replace each character with *
                  onChange={(e) => form.setValue("password", e.target.value)} // Update the form value
                />
              </FormControl>

              <FormMessage />
            </FormItem>
          )}
        />
        <Button
          type="submit"
          className="dark:text-text  bg-red dark:hover:  dark:bg-mantle hover:bg-yellow dark:hover:bg-yellow hover: w-[180px] whitespace-nowrap rounded-sm border-transparent font-medium transition duration-150 ease-in-out focus:outline-none "
        >
          Submit
        </Button>
      </form>
    </Form>
  )
}
