"use client"
import React, { useEffect, useState } from "react"
import { UsePostPlayerRival } from "@/app/axios/usePostApi"
import { usePlayerRivalList } from "@/app/axios/useFetchApi"
import { Input } from "./ui/input"
import { RivalData } from "@/lib/types"
import { ApiFetch } from "@/lib/api"

const RivalComponent = () => {
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [successMessage, setSuccessMessage] = useState<string | null>(null)
  const [showAccessCode, setShowAccessCode] = useState(false)
  const [ownRivalCode, setOwnRivalCode] = useState(-1)
  const [targetRivalCode, setTargetRivalCode] = useState(0)
  const [rivals, setRivals] = useState<{ username: string }[]>([])
  const [refreshRivalList, setRefreshRivalList] = useState(false)

  const { postRival } = UsePostPlayerRival({
    onPostSuccess: (data) => {
      setSuccessMessage("Rival added successfully!")
      setError(null)
      // Set refreshRivalList to true after posting a rival
      setRefreshRivalList(true)
    },
    setLoading,
    setError,
  })

  const handlePostRival = () => {
    if (targetRivalCode) {
      postRival({
        rivalCode: targetRivalCode,
      })
    }
  }
  
  usePlayerRivalList({
    setPlayerRivalList: setRivals,
    setLoading,
    setError,
    refreshRivalList,
  })

  useEffect(() => {
    async function fetchData() {
      const user = (await ApiFetch<UserDataResponse>("/SDHD/user")).body.body;

      setOwnRivalCode(user.rivalCode);
    }

    fetchData();
  }, []);

  useEffect(() => {
    const successTimeout = setTimeout(() => {
      setSuccessMessage(null)
    }, 3000)

    return () => {
      clearTimeout(successTimeout)
    }
  }, [successMessage])

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      <div className="flex w-full flex-col items-start md:w-auto">
        <div className="relative mt-1">
          <label className="block pb-1 pt-2 text-sm font-medium text-typography">
            Enter Rival Aime Card:
          </label>
          <Input
            type="number"
            placeholder="Enter Rival Code:"
            onChange={(e) => setTargetRivalCode(e.target.valueAsNumber)}
            className="w-[300px] rounded-md border-gray-300 py-2 pl-3 pr-10 shadow-sm focus:outline-none sm:w-[200px] sm:text-sm md:w-[200px] lg:w-[300px]"
          />
        </div>
        {successMessage && (
          <div className="text-green mt-2">{successMessage}</div>
        )}
        <div className="mt-4 flex items-center space-x-2">
          <button
            onClick={handlePostRival}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Add Rival
          </button>
          <button
            onClick={() => setShowAccessCode(!showAccessCode)}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            {showAccessCode ? "Hide Rival Code" : "Show Rival Code"}
          </button>
        </div>
        {showAccessCode && (
          <div>
            <label className="text-sm font-medium text-typography">
              Your Rival code:
            </label>
            <div className="text-lg font-bold text-typography">
              {ownRivalCode}
            </div>
          </div>
        )}
        {rivals.length > 0 && (
          <div>
            <label className="text-xs font-medium text-typography">
              Rivals need to have played once on the most recent version that
              your server supports to show up here.
            </label>
            <div className="mb-1">
              {" "}
              <label className="text-sm font-medium text-typography">
                Your Rivals:
              </label>
            </div>
            <div className="pb-2">
              <ul>
                {rivals.map((rival, index) => (
                  <li key={index} className="text-md font-bold ">
                    Rival {index + 1}: {rival.username}
                  </li>
                ))}
              </ul>
            </div>
          </div>
        )}
      </div>
    </div>
  )
}

export default RivalComponent
