"use client"
import React, { useEffect, useState } from "react"
import Image from "next/image"
import { useFetchPlayerScoreLog } from "@/app/axios/useFetchApi"
import { useSettings } from "@/app/context/SettingsContext"
import { Input } from "./ui/input"
import { JacketImageProps, NavigationButtonsProps, getDifficultyClass, getDifficultyText, getGrade, getRatingChangeColor } from "@/lib/utils"
import { ScoreCardProps } from "@/lib/types"


// JacketImage Component
const JacketImage: React.FC<JacketImageProps> = ({ jacketPath }) => (
  <Image
    src={jacketPath}
    alt="Character Image"
    width={90}
    height={90}
    className="border-sm ml-1 mt-4  border-4 border-songjacketborder dark:border-gray-400"
  />
)

const ScoreCard: React.FC<ScoreCardProps> = ({
  userPlayDate,
  title,
  rating_change,
  genre,
  score,
  isNewRecord,
  isAllJustice,
  judgeJustice,
  judgeAttack,
  chartId,
  judgeGuilty,
  artist,
  judgeHeaven,
  judgeCritical,
  level,
  isClear,
  isFullCombo,
  maxCombo,
  jacketPath,
  rating,
}) => {
  const formattedJacketPath = `${process.env.NEXT_PUBLIC_CDN
    }JacketArt/${jacketPath.slice(0, -3)}png`
  const realJusticeCritical = judgeCritical + judgeHeaven
  const { isBestPossibleEnabled } = useSettings()

  return (
    <div className="h-50  rounded-sm bg-cardsectionbackgroundcolor p-2 text-typography ">
      <div className="flex items-center justify-between">
        <span className="text-lg text-typography">{userPlayDate}</span>
        <div className="flex justify-end">
          <div className="flex flex-col items-end justify-center">
            <div className="flex items-center">
              <span
                className={`justify-center rounded-sm p-1 px-2 text-center text-sm font-bold ${getDifficultyClass(
                  chartId,
                )} text-scorecardbadgetypography`}
              >
                {getDifficultyText(chartId)}{" "}
                {level !== undefined ? level.toString() : "N/A"}{" "}
              </span>
              {isNewRecord !== 0 && isNewRecord ? (
                <span className="bg-color13 ml-2 rounded-sm bg-newbadgecolor p-1 px-2 text-sm font-bold text-scorecardbadgetypography">
                  NEW!!
                </span>
              ) : (
                <span className=""></span>
              )}
            </div>
          </div>
        </div>
      </div>
      <div className={`text-xs ${getRatingChangeColor(rating_change)}`}>
        Rating: {rating_change}&nbsp;
        {isBestPossibleEnabled && (
          <span className={`text-xs ${getRatingChangeColor(rating_change)}`}>
            {(rating / 100).toFixed(2)}
          </span>
        )}
      </div>

      <div className="flex">
        <div className="flex items-start space-x-4">
          <JacketImage jacketPath={formattedJacketPath} />
          <div className="flex flex-col justify-center pt-3">
            <h2 className="w-[200px] truncate pb-2 text-xs text-typography  lg:w-[310px]">
              {title}
            </h2>
            <div className="h-[1] w-[180px] overflow-hidden truncate pb-2 text-xs text-typography">
              {artist}
            </div>
            <div className="text-xs  text-typography">{genre}</div>
          </div>
        </div>
      </div>
      <div className="flex pl-1 pt-4">
        <div
          className={` mr-2 rounded-sm bg-scorecardbadge px-2 py-1 text-sm font-bold text-scorecardbadgetypography  ${isFullCombo
            ? "bg-scorecardbadge"
            : isAllJustice
              ? "dark:bg-green-500"
              : ""
            }`}
        >
          {isAllJustice
            ? "All Justice"
            : isFullCombo
              ? "Full Combo"
              : `Combo: ${maxCombo}`}
        </div>
        <div
          className={`mr-2 rounded-sm  bg-scorecardbadge px-4 py-1 text-sm font-bold text-scorecardbadgetypography  ${isClear === 0 ? "bg-scorecardbadge" : ""
            }`}
        >
          {isClear === 1 ? "CLEAR" : "UNCLEARED"}
        </div>
        <div className="bg-yellow rounded-sm bg-scorecardbadge px-4 py-1  text-sm font-bold text-scorecardbadgetypography ">
          {getGrade(score)}
        </div>
      </div>
      <div className="flex items-center justify-start pt-2">
        <div className="pr-1 text-xs text-scoretext md:pr-2">
          Score: {score.toLocaleString()}
        </div>
        <div className="flex items-center justify-start">
          <div className="pr-1 text-xs text-justicecriticaltext md:pr-2 ">
            Justice Critical: {realJusticeCritical}
          </div>
          <div className="pr-1 text-xs text-justicetext md:pr-2">
            Justice: {judgeJustice}
          </div>
          <div className="pr-1 text-xs text-attacktext md:pr-2">
            Attack: {judgeAttack}
          </div>
          <div className="text-xs text-misstext">Miss: {judgeGuilty}</div>
        </div>
      </div>
    </div>
  )
}

// NavigationButtons Component
const NavigationButtons: React.FC<NavigationButtonsProps> = ({
  currentPage,
  totalPages,
  onPageChange,
  onNext,
  onPrevious,
}) => {
  // Only show a maximum of 5 page buttons around the current page
  const rangeStart = 5 * Math.floor((currentPage - 1) / 5) + 1
  const rangeEnd = Math.min(rangeStart + 4, totalPages)

  const pages = Array.from(
    { length: rangeEnd - rangeStart + 1 },
    (_, index) => rangeStart + index,
  )

  return (
    <div className="flex items-center justify-center space-x-1 ">
      <button
        onClick={onPrevious}
        disabled={currentPage === 1}
        className="rounded bg-paginationbackground px-4 font-bold text-paginationtypography hover:text-paginationtypographyhover   disabled:opacity-40"
      >
        Previous
      </button>
      {pages.map((page) => (
        <button
          key={page}
          onClick={() => onPageChange(page)}
          disabled={currentPage === page}
          className={`rounded bg-paginationbackground px-2 font-bold text-paginationtypography hover:text-paginationtypographyhover ${currentPage === page ? " " : ""
            }`}
        >
          {page}
        </button>
      ))}
      <button
        onClick={onNext}
        disabled={currentPage === totalPages}
        className="rounded bg-paginationbackground px-4  font-bold text-paginationtypography hover:text-paginationtypographyhover  disabled:opacity-40"
      >
        Next
      </button>
    </div>
  )
}

// ScoreCardList Component
const ScoreCardList = () => {
  const [profileData, setPlayerScoreLog] = useState<any[]>([])
  const [loading, setLoading] = useState<boolean>(true)
  const [error, setError] = useState<string | null>(null)
  const [itemsPerPage] = useState<number>(9)
  const [currentPage, setCurrentPage] = useState<number>(1)
  const [searchQuery, setSearchQuery] = useState("")
  const [filteredData, setFilteredData] = useState<any[]>([])

  useFetchPlayerScoreLog({ setPlayerScoreLog, setLoading, setError })

  useEffect(() => {
    const queryLower = searchQuery.toLowerCase()

    const filtered = profileData.filter((item) => {
      // Check if the query is present in the title, artist, level, or grade
      const titleMatches = item.title.toLowerCase().includes(queryLower)
      const artistMatches = item.artist.toLowerCase().includes(queryLower)
      const levelMatches = item.level
        ? item.level.toString().toLowerCase().includes(queryLower)
        : false
      const gradeMatches = getGrade(item.score)
        .toLowerCase()
        .includes(queryLower)

      return titleMatches || artistMatches || levelMatches || gradeMatches
    })

    setFilteredData(filtered)
  }, [searchQuery, profileData])

  const totalPages = Math.ceil(filteredData.length / itemsPerPage)

  // Get current items for the current page
  const indexLastItem = currentPage * itemsPerPage
  const indexFirstItem = indexLastItem - itemsPerPage
  const currentItems = filteredData.slice(indexFirstItem, indexLastItem)

  // Go to the next page
  const handleNext = () => {
    setCurrentPage((prevCurrentPage) =>
      Math.min(prevCurrentPage + 1, totalPages),
    )
  }

  // Go to the previous page
  const handlePrevious = () => {
    setCurrentPage((prevCurrentPage) => Math.max(prevCurrentPage - 1, 1))
  }

  // Go to the specific page
  const handlePageChange = (page: number) => {
    setCurrentPage(page)
  }

  if (loading) {
    return <div></div> // Display loading state
  }

  if (error) {
    return <div>Error: {error}</div> // Display error state
  }

  return (
    <div className=" w-[405px] sm:w-[640px] md:w-[840px] lg:w-[690px] xl:w-[790px] 2xl:w-[1390px]">
      <div className="">
        <Input
          type="text"
          placeholder="Search by artist, level, song title, or grade. "
          className={` focus-visible: w-[395px] bg-transparent text-typography transition duration-300 ease-in-out focus:outline-none  dark:border-gray-300  dark:bg-transparent sm:w-[640px] md:w-[840px] lg:w-[690px] xl:w-[790px] 2xl:w-[1390px]`}
          value={searchQuery}
          onChange={(e) => setSearchQuery(e.target.value)}
        />
      </div>
      <div className="grid w-[405px] grid-cols-1 sm:w-[640px] sm:grid-cols-1 md:w-[840px]  md:grid-cols-1 lg:w-[700px] lg:grid-cols-1 xl:w-[790px] xl:grid-cols-1 2xl:w-[1400px] 2xl:grid-cols-3">
        {currentItems.map((scoreCardInfo, index) => (
          <div key={index} className="dark:bg-crust mb-2 mr-2 mt-2 rounded-sm">
            <ScoreCard {...scoreCardInfo} />
          </div>
        ))}
      </div>
      <div className="mt-2 flex  justify-around">
        <div className="rounded-md">
          <NavigationButtons
            currentPage={currentPage}
            totalPages={totalPages}
            onPageChange={handlePageChange}
            onNext={handleNext}
            onPrevious={handlePrevious}
          />
        </div>
      </div>
    </div>
  )
}

export default ScoreCardList
