/* eslint-disable @next/next/no-img-element */

"use client"
import React, { useState, useEffect } from "react"
import { UsePostSystemVoice } from "@/app/axios/usePostApi"
import { UsePlayerVoiceId } from "@/app/axios/useFetchApi"
import { UsePlayerDuelCompletions } from "@/app/axios/useFetchApi"
import AudioPlayer from "./shared/audioPlayer/page"
import { DropdownVoiceProps, PlayerVoiceData } from "@/lib/types"

const Dropdown: React.FC<DropdownVoiceProps & { className?: string }> = ({
  options,
  onChange,
  str,
  id,
  className,
}) => {
  return (
    <div className={`dropdown-container relative ${className}`}>
      <label className="block pb-1 pt-2 text-sm font-medium text-typography">
        {str}
      </label>
      <div className="relative mt-1">
        <select
          value={id}
          onChange={(e) => onChange(e.target.value)}
          className=" w-[230px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium text-typography transition duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
        >
          {options.map((option, index) => (
            <option
              key={`${option.id}-${index}`}
              value={option.id}
              className="text-typography"
            >
              {option.str}
            </option>
          ))}
        </select>
      </div>
    </div>
  )
}

const SystemVoiceComponent = () => {
  const [systemVoiceData, setSystemVoiceData] = useState<PlayerVoiceData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [duelData, setDuelData] = useState<{ duelId: string; str: string }[]>(
    [],
  )
  const [selectedDuelId, setSelectedDuelId] = useState<string>("")
  const [playerInfoLoaded, setPlayerInfoLoaded] = useState(false)

  UsePlayerVoiceId({
    setPlayerVoiceId: setSystemVoiceData,
    setLoading,
    setError,
  })

  UsePlayerDuelCompletions({
    setPlayerDuelCompletions: setDuelData,
    setLoading,
    setError,
    onSuccess: (data) => { },
  })

  useEffect(() => {
    if (systemVoiceData.length > 0 && !playerInfoLoaded) {
      const initialVoiceId = systemVoiceData[0].voiceId
      setSelectedDuelId(initialVoiceId)
      setPlayerInfoLoaded(true)
    }
  }, [systemVoiceData, playerInfoLoaded])

  const { postVoiceID } = UsePostSystemVoice({
    onPostSuccess: (data) => {
      console.log("Data posted successfully:", data)
    },
    setLoading,
    setError,
  })

  const handleSelectionChange = (part: keyof PlayerVoiceData, id: string) => {
    if (part === "voiceId") {
      setSelectedDuelId(id)
    }

    setSystemVoiceData(
      systemVoiceData.map((data, index) =>
        index === 0 ? { ...data, [part]: id } : data,
      ),
    )
  }

  const handlePostData = () => {
    if (systemVoiceData.length > 0) {
      const { voiceId } = systemVoiceData[0]

      const dataToPost = {
        voiceId: selectedDuelId,
      }

      postVoiceID(dataToPost)
      console.log("Attempting to post data", dataToPost)
    }
  }

  if (loading) return <div></div>
  if (error) return <div>Error: {error}</div>
  if (!Array.isArray(systemVoiceData) || systemVoiceData.length === 0) {
    return <div>No player data found.</div>
  }

  const DEFAULT_IMAGE = `${process.env.NEXT_PUBLIC_CDN}systemVoice/CHU_UI_SystemVoice_00000001.png`

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      {selectedDuelId && (
        <img
          className="h-[128px] w-[200px]"
          src={`${process.env.NEXT_PUBLIC_CDN
            }systemVoiceThumbnails/CHU_UI_SystemVoice_${selectedDuelId
              .toString()
              .padStart(8, "0")}.png`}
          alt="System Voice"
          onError={(e) => {
            e.currentTarget.src = DEFAULT_IMAGE
          }}
        />
      )}
      <div className="flex w-full flex-col items-start md:w-auto">
        <Dropdown
          options={duelData.map((data) => ({
            str: data.str,
            id: data.duelId,
            sortName: "",
          }))}
          onChange={(value) => handleSelectionChange("voiceId", value)}
          str="Duel Options: "
          id={selectedDuelId}
        />
        <div className="mt-4 flex items-center">
          <button
            onClick={handlePostData}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Update System Voice
          </button>

          <div>
            <AudioPlayer
              src={`${process.env.NEXT_PUBLIC_CDN
                }systemVoice/systemvoice0${selectedDuelId
                  .toString()
                  .padStart(3, "0")}/00001.wav`}
            />
          </div>
        </div>
      </div>
    </div>
  )
}

export default SystemVoiceComponent
