/* eslint-disable @next/next/no-img-element */
"use client"

import React, { useState, useEffect } from "react"
import { UsePlayerTeams } from "@/app/axios/useFetchApi"
import { UsePostPlayerTeamProfile } from "@/app/axios/usePostApi"
import { UsePostPlayerTeam } from "@/app/axios/usePostApi"
import { Input } from "./ui/input"
import { PlayerTeamData } from "@/lib/types"

const PlayerTeamComponent = () => {
  const [playerTeamData, setPlayerTeams] = useState<PlayerTeamData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [newTeamName, setNewTeamName] = useState<string>("")
  const [selectedTeam, setSelectedTeam] = useState<string>("")
  const [successMessage, setSuccessMessage] = useState<string | null>(null)
  const [refreshTeams, setRefreshTeams] = useState(false)

  UsePlayerTeams({ setPlayerTeams, setLoading, setError })

  const { postTeamName } = UsePostPlayerTeam({
    onPostSuccess: (data) => {
      console.log("Data posted successfully:", data)
      setSuccessMessage("Team created successfully!")

      setTimeout(() => {
        setSuccessMessage(null)
      }, 3000)

      setNewTeamName("")
      setPlayerTeams(data.teams)
    },
    setLoading,
    setError,
  })

  const { postTeamNameProfile } = UsePostPlayerTeamProfile({
    onPostSuccess: (data) => {
      console.log("Player team profile updated successfully:", data)
    },
    setLoading,
    setError,
  })

  const handlePostData = () => {
    if (newTeamName.trim() !== "") {
      const isTeamNameExists = playerTeamData.some(
        (team) => team.teamName.toLowerCase() === newTeamName.toLowerCase(),
      )

      if (isTeamNameExists) {
        setError("Team name already exists. Please choose a different name.")
        setSuccessMessage(null)

        setTimeout(() => {
          setError(null)
        }, 3000)

        return
      }

      const dataToPost = { teamName: newTeamName }
      postTeamName(dataToPost)
      console.log("Attempting to post data", dataToPost)
    }
  }

  const handleSelectTeam = (e: React.ChangeEvent<HTMLSelectElement>) => {
    setSelectedTeam(e.target.value)
  }

  const handlePostPlayerTeamProfile = () => {
    if (selectedTeam) {
      const dataToPost = { teamId: selectedTeam }
      postTeamNameProfile(dataToPost)
      console.log("Posting player team profile data", dataToPost)
    } else {
      console.error("No team selected")
    }
  }

  useEffect(() => {
    if (refreshTeams) {
      setRefreshTeams(false)
    }
  }, [refreshTeams])

  if (loading) return <div>Loading...</div>

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      <div className="flex w-full flex-col">
        <div className="mb-4 flex items-center">
          <Input
            type="text"
            placeholder="Enter Team Name"
            value={newTeamName}
            onChange={(e) => setNewTeamName(e.target.value)}
            className=" hover:bg-yellow w-[230px] whitespace-nowrap rounded-sm border border-transparent  bg-background px-3 py-2 font-medium transition  duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
          />
          <div className="pl-1">
            <button
              onClick={handlePostData}
              className="mr-2 w-[180px] whitespace-nowrap rounded-sm border  border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
            >
              Create Team
            </button>
          </div>
        </div>

        <div className="mb-4 flex items-center">
          <select
            value={selectedTeam}
            onChange={handleSelectTeam}
            className=" w-[230px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium text-typography transition duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
          >
            <option value="">Select a Team</option>
            {playerTeamData.map((team) => (
              <option key={team.id} value={team.id}>
                {team.teamName}
              </option>
            ))}
          </select>
          <div className="pl-1">
            <button
              onClick={handlePostPlayerTeamProfile}
              className="w-[180px] whitespace-nowrap rounded-sm border  border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
            >
              Set Player Team
            </button>
          </div>
        </div>
        {successMessage && (
          <div className="text-green mb-2">{successMessage}</div>
        )}
        {error && <div className="text-red mb-2">{error}</div>}
      </div>
    </div>
  )
}

export default PlayerTeamComponent
