"use client"

import React, { useEffect, useState } from "react"
import Image from "next/image"
import { useBestTop } from "@/app/axios/useFetchApi"
import { usePlayerRecentRatingTable } from "@/app/axios/useFetchApi"
import { useSettings } from "@/app/context/SettingsContext"
import { ScrollArea } from "@/components/ui/scroll-area"
import { Separator } from "./ui/separator"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
const PlayerBestTopScores = () => {
  const [bestTop, setBestTop] = useState<any[]>([])
  const [recentRatingTable, setPlayerRecentRatingTable] = useState<any[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [selectedSegment, setSelectedSegment] = useState("Top30") // Set "Top30" as the default
  const [displayedData, setDisplayedData] = useState<any[]>([])
  const { isAverageEnabled } = useSettings()
  const [averageTop30Rating, setAverageTop30Rating] = useState<number>(0) // New state for average rating
  const [averageRecentRating, setAverageRecentRating] = useState<number>(0) // New state for average recent rating

  useBestTop({ setBestTop, setLoading, setError })
  usePlayerRecentRatingTable({
    setPlayerRecentRatingTable,
    setLoading,
    setError,
  })
  useEffect(() => {
    const sortedData =
      selectedSegment === "Top30"
        ? [...bestTop].sort(
          (a, b) => (parseFloat(b.rating) || 0) - (parseFloat(a.rating) || 0),
        )
        : [...recentRatingTable].sort(
          (a, b) => (parseFloat(b.rating) || 0) - (parseFloat(a.rating) || 0),
        )
    // Filter out entries with undefined or null ratings
    const filteredData = sortedData.filter(
      (entry) => entry.rating !== undefined && entry.rating !== null,
    )

    if (selectedSegment === "Recent10") {
      setDisplayedData(filteredData.slice(0, 10))

      // Calculate average of recent 10 ratings from displayed data
      const recent10Ratings = filteredData
        .slice(0, 10)
        .map((entry) => parseFloat(entry.rating))
      const averageRecentRatingValue =
        recent10Ratings.length > 0
          ? recent10Ratings.reduce((sum, rating) => sum + rating, 0) /
          recent10Ratings.length
          : 0
      setAverageRecentRating(averageRecentRatingValue)
    } else {
      const increasedRatingData = filteredData.filter(
        (entry) =>
          entry.rating_change === "Increase" ||
          entry.score_change === "Increase",
      )
      const uniqueData = increasedRatingData.filter(
        (entry, index, self) =>
          index === self.findIndex((e) => e.title === entry.title),
      )

      setDisplayedData(uniqueData.slice(0, 30))

      const top30Ratings = uniqueData
        .slice(0, 30)
        .map((entry) => parseFloat(entry.rating))
      console.log(top30Ratings)

      const averageRating =
        top30Ratings.length > 0
          ? top30Ratings.reduce((sum, rating) => sum + rating, 0) /
          top30Ratings.length
          : 0
      setAverageTop30Rating(averageRating)
    }
  }, [bestTop, recentRatingTable, selectedSegment])
  return (
    <div className="justify-center md:mx-auto md:px-0 ">
      <div className="flex justify-start pb-2">
        <div className="inline-flex rounded-md shadow-sm " role="group">
          <Tabs defaultValue="top30">
            <TabsList>
              <TabsTrigger
                value="top30"
                onClick={() => setSelectedSegment("Top30")}
              >
                Top 30
              </TabsTrigger>
              <TabsTrigger
                value="recent10"
                onClick={() => setSelectedSegment("Recent10")}
              >
                Recent 10
              </TabsTrigger>
            </TabsList>

            <TabsContent value="top30">
              {/* Content for Top 30 */}
              {selectedSegment === "Top30" && <div></div>}
            </TabsContent>

            <TabsContent value="recent10">
              {/* Content for Recent 10 */}
              {selectedSegment === "Recent10" && <div></div>}
            </TabsContent>
          </Tabs>
        </div>
      </div>

      <div>
        {loading && <div></div>}
        {error && <div>Error: {error}</div>}
        <div className=""></div>
        <ScrollArea className="h-[950px] w-[340px] rounded-md border">
          <div className="p-4">
            <div className=" pb-2 text-typography ">
              {isAverageEnabled && selectedSegment === "Top30" && (
                <p>Average Rating {(averageTop30Rating / 100).toFixed(2)}</p>
              )}
              {isAverageEnabled && selectedSegment === "Recent10" && (
                <p>Average Rating {(averageRecentRating / 100).toFixed(2)}</p>
              )}
            </div>
            {displayedData.map((user, index) => {
              const formattedJacketPath = `${process.env.NEXT_PUBLIC_CDN
                }JacketArt/${user.jacketPath.slice(0, -3)}png`

              return (
                <>
                  <div key={index} className="flex items-start ">
                    <div className="flex-none pb-2">
                      <Image
                        src={formattedJacketPath}
                        alt={`${user.title} Jacket Art`}
                        width={90}
                        height={90}
                        className="border-sm border-4 border-songjacketborder"
                      />
                    </div>
                    <div className="flex-grow pl-2">
                      <div className="text-typography mb-1">
                        <span className=" text-typography text-xl">
                          {" "}
                          {index + 1}.
                        </span>{" "}
                        {user.title}
                      </div>
                      <div className="text-typography">
                        {user.level}
                        <span className="text-bestrecentratingcolor">
                          {" "}
                          {(user.rating / 100).toFixed(2)}
                        </span>
                      </div>
                      <span className="text-bestrecentratingcolor">
                        {parseInt(user.score).toLocaleString()}
                      </span>
                    </div>
                  </div>
                  <div>
                    <Separator className="my-2" />
                  </div>
                </>
              )
            })}
          </div>
        </ScrollArea>
      </div>
    </div>
  )
}

export default PlayerBestTopScores
