"use client"
import { UsePostTrophy } from "@/app/axios/usePostApi"
import React, { useState } from "react"
import {
  UsePlayerProfileTrophies,
  UsePlayerTrophies,
} from "@/app/axios/useFetchApi"
import { DropdownProps, PlayerData, PlayerTrophiesData } from "@/lib/types"

const Dropdown: React.FC<DropdownProps & { className?: string }> = ({
  options,
  onChange,
  label,
  trophyId,
  className,
}) => {
  return (
    <div className={`dropdown-container relative ${className}`}>
      <label className="dark:text-blue block pb-1 pt-2 text-sm font-medium  ">
        {label}
      </label>
      <div className="relative mt-1">
        <select
          value={trophyId}
          onChange={(e) => onChange(e.target.value)}
          className=" w-[230px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium text-typography transition duration-150  ease-in-out focus:outline-none sm:w-[280px] md:w-[280px] lg:w-[280px]"
        >
          {options.map((option, index) => (
            <option
              key={`${option.trophyId}-${index}`}
              value={option.trophyId}
              className=" dark:text-white"
            >
              {option.name}{" "}
              {option.rareType === 6
                ? "(MASTER ALL JUSTICE)"
                : option.rareType === 4
                  ? "(EXPERT ALL JUSTICE)"
                  : ""}
            </option>
          ))}
        </select>
      </div>
    </div>
  )
}

const PlayerTropyComponent = () => {
  const [playerData, setPlayerProfileTrophies] = useState<PlayerData[]>([])

  const [PlayerTrophies, setPlayerTrophies] = useState<PlayerTrophiesData[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  UsePlayerTrophies({ setPlayerTrophies, setLoading, setError })
  UsePlayerProfileTrophies({ setPlayerProfileTrophies, setLoading, setError })

  const { postTrophy } = UsePostTrophy({
    onPostSuccess: (data) => {
      console.log(data)
    },
    setLoading,
    setError,
  })

  const handlePostData = () => {
    if (playerData.length > 0) {
      const { trophyId } = playerData[0]
      const dataToPost = { trophyId }
      console.log("Data to be posted:", dataToPost)
      postTrophy(dataToPost)
    }
  }

  if (loading) return <div></div>
  if (error) return <div>Error: {error}</div>
  if (!Array.isArray(playerData) || playerData.length === 0) {
    return <div>No player data found.</div>
  }

  return (
    <div className="items-center justify-center rounded-sm bg-subsectionbackgroundcolor pl-4 pt-4 md:flex-row">
      <div className="items- flex w-full flex-col md:w-auto">
        <Dropdown
          options={PlayerTrophies}
          onChange={(value) =>
            setPlayerProfileTrophies([
              { ...playerData[0], trophyId: Number(value) },
            ])
          }
          label="System Trophy: "
          className="text-typography"
          trophyId={playerData[0].trophyId}
        />

        <div className=" mt-4">
          <button
            onClick={handlePostData}
            className="mb-3 whitespace-nowrap rounded-sm border border-transparent bg-buttonbackgroundcolor px-3 py-2 font-medium text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Update Trophy
          </button>
        </div>
      </div>
    </div>
  )
}

export default PlayerTropyComponent
