"use client"
import React, { useEffect, useState } from "react"
import { UsePostNewKeychip } from "@/app/axios/usePostApi"
import { Input } from "./ui/input"
import { ApiFetch } from "@/lib/api"
const NewKeychipComponent = () => {
  const initialKeychipData = {
    arcade_nickname: "",
    name: "",
    serial: "",
    namcopcbid: "",
  }

  const [userId, setUserId] = useState(0)
  const [keychipData, setKeychipData] = useState(initialKeychipData)
  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)
  const [accessCodeError, setAccessCodeError] = useState<string | null>(null)
  const [successMessage, setSuccessMessage] = useState<string>("")

  useEffect(() => {
    async function fetchData() {
      const user = (await ApiFetch<UserDataResponse>("/SDHD/user")).body.body;

      setUserId(user.userId);
    }

    fetchData();
  }, []);

  const { createNewKeychip } = UsePostNewKeychip({
    onPostSuccess: (data) => {
      setSuccessMessage("Keychip created successfully!")

      setKeychipData(initialKeychipData)
      setAccessCodeError(null)
    },
    setLoading,
    setError,
  })

  const handleChange = (
    e: React.ChangeEvent<HTMLInputElement | HTMLSelectElement>,
  ) => {
    setKeychipData({ ...keychipData, [e.target.name]: e.target.value })
  }

  const allowedUserIds = [10000, 10011];

  const handleSubmit = () => {
    // Check if any of the input fields are empty
    if (
      keychipData.name.trim() === "" ||
      keychipData.arcade_nickname.trim() === "" ||
      keychipData.serial.trim() === ""
    ) {
      setAccessCodeError("Please fill in all the required fields.")
      // Set red color and vanish after 3 seconds
      setTimeout(() => {
        setAccessCodeError(null)
      }, 3000)
      return
    }

    if (allowedUserIds.includes(userId)) {
      createNewKeychip(keychipData)
      console.log("Submitting keychip data", keychipData)
    } else {
      setAccessCodeError("Invalid access code. Please check and try again.")
    }
  }
  useEffect(() => {
    let timeoutId: NodeJS.Timeout
    if (successMessage) {
      timeoutId = setTimeout(() => {
        setSuccessMessage("")
      }, 3000)
    }
    return () => {
      clearTimeout(timeoutId)
    }
  }, [successMessage])

  const generateRandomSerial = () => {
    let uniqueNumbers = ""
    while (uniqueNumbers.length < 4) {
      const digit = Math.floor(Math.random() * 10)
      if (!uniqueNumbers.includes(digit.toString())) {
        uniqueNumbers += digit
      }
    }
    const randomNumbers = Math.floor(1000 + Math.random() * 9000)
    const randomSerial = `A69E01A${uniqueNumbers}${randomNumbers}`
    setKeychipData({ ...keychipData, serial: randomSerial })
  }

  if (loading) return <div>Loading...</div>
  if (error) return <div>Error: {error}</div>

  if (!allowedUserIds.includes(userId)) {
    return <div></div>
  }
  return (
    <div className="mx-auto  w-[390px] rounded-sm bg-subsectionbackgroundcolor p-2">
      <label className="mb-2 block pb-1 pt-1 text-sm font-bold text-black text-typography">
        Create New Keychip
      </label>
      {successMessage && (
        <div className="text-green mb-4">{successMessage}</div>
      )}
      {accessCodeError && (
        <div className="text-red mb-4">{accessCodeError}</div>
      )}
      <div>
        <div className="mb-4">
          <Input
            type="text"
            name="name"
            value={keychipData.name}
            onChange={handleChange}
            placeholder="Arcade Name"
            className="w-full rounded-md border border-gray-300 p-2 focus:outline-none focus:ring-2 focus:ring-blue-500"
          />
        </div>
        <div className="mb-4">
          <Input
            type="text"
            name="arcade_nickname"
            value={keychipData.arcade_nickname}
            onChange={handleChange}
            placeholder="Arcade Nickname"
            className="w-full rounded-md border  border-gray-300 p-2 focus:outline-none focus:ring-2 focus:ring-blue-500"
          />
        </div>
        <div className="">
          <Input
            type="text"
            name="serial"
            value={keychipData.serial}
            onChange={handleChange}
            placeholder="Serial Number"
            className="w-full rounded-md border border-gray-300 p-2 focus:outline-none focus:ring-2 focus:ring-blue-500"
          />
        </div>
        <div className="flex flex-col items-center pb-2 pt-4">
          <button
            onClick={generateRandomSerial}
            className="hover:bg-red mb-3 w-[220px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium  text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Generate Random Serial
          </button>
          <button
            onClick={handleSubmit}
            className="hover:bg-red mb-3 w-[220px] whitespace-nowrap rounded-sm border border-transparent bg-background px-3 py-2 font-medium  text-typography transition duration-150 ease-in-out hover:bg-buttonhovercolor hover:text-buttontexthovercolor focus:outline-none"
          >
            Create New Keychip
          </button>
        </div>
      </div>
    </div>
  )
}

export default NewKeychipComponent
