"use client"
import { useState } from "react"
import Link from "next/link"
import { useRouter } from "next/navigation"
import { serialize } from "cookie"
import { AxiosError } from "axios"
import { ApiFetch } from "@/lib/api"

const removeCookie = (cookieName: string): string =>
  serialize(cookieName, "", {
    httpOnly: true, // Change to true for better security
    secure: process.env.NODE_ENV === "production",
    sameSite: "strict",
    maxAge: -1,
    path: "/",
  })

const removeLoginInfoCookie = async (): Promise<void> => {
  const serializedToken = removeCookie("ArtemisAPI_SESSION");
  
  document.cookie = serializedToken;
  await ApiFetch("/SDHD/logoutUser", { method: "POST" }, true, true);
}

const NavigationBar = () => {
  const [isMenuOpen, setIsMenuOpen] = useState(false)
  const { push } = useRouter()

  const handleLogout = async () => {
    try {
      console.log("Logging out...")
      await removeLoginInfoCookie()
      console.log("Logout successful.")
      push("/")
    } catch (error) {
      console.error("Logout failed:", error)
    }
  }
  const handleMenuClick = () => {
    setIsMenuOpen(!isMenuOpen)
  }
  return (
    <div>
      <nav className="z-50 mt-1 flex items-center justify-between rounded-sm p-5">
        {/* Hamburger Icon */}
        <div className="z-50 md:hidden" onClick={handleMenuClick}>
          <svg
            className="h-6 w-6"
            fill="none"
            stroke="#CAD3F5"
            viewBox="0 0 24 24"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={2}
              d="M4 6h16M4 12h16m-7 6h7"
            />
          </svg>
        </div>
        <div className="hidden flex-1 justify-end md:flex">
          <Link
            href="/chunithm"
            className="pl-2 font-bold uppercase text-typography  hover:text-texthover  "
          >
            SCORES
          </Link>
          <Link
            href="/userbox"
            className="pl-2 font-bold uppercase  text-typography   hover:text-texthover  "
          >
            USERBOX
          </Link>
          <Link
            href="/management"
            className="pl-2 font-bold uppercase text-typography hover:text-texthover "
          >
            MANAGEMENT
          </Link>
          <Link
            href="/settings"
            className="pl-2 font-bold uppercase text-typography    hover:text-texthover "
          >
            SETTINGS
          </Link>

          <div className="pl-2 font-bold uppercase ">
            <button
              onClick={handleLogout}
              className="text-bg-typography font-bold uppercase text-typography hover:text-texthover "
            >
              Logout
            </button>
          </div>
        </div>
      </nav>
      {/* Side Menu */}
      <div
        className={`fixed left-0 top-0 z-50 h-full w-64 transform bg-subsectionbackgroundcolor transition-all duration-300 ease-in-out ${
          isMenuOpen ? "translate-x-0 " : "-translate-x-full"
        }`}
      >
        <div className="mt-10 flex flex-col">
          <Link
            href="/chunithm"
            className="pb-2 pl-2 font-bold uppercase text-typography   hover:text-texthover "
          >
            SCORES
          </Link>
          <Link
            href="/userbox"
            className="pb-2 pl-2 font-bold uppercase text-typography    hover:text-texthover "
          >
            USERBOX
          </Link>
          <Link
            href="/management"
            className="pb-2 pl-2 font-bold uppercase text-typography  hover:text-texthover "
          >
            MANAGEMENT
          </Link>
          <Link
            href="/settings"
            className="pb-2 pl-2 font-bold uppercase text-typography    hover:text-texthover "
          >
            SETTINGS
          </Link>

          <div className="text-bg-typography pb-2 pl-2 font-bold uppercase hover:text-texthover ">
            <button
              onClick={handleLogout}
              className="text-bg-typography font-bold uppercase text-typography hover:text-texthover "
            >
              Logout
            </button>
          </div>
        </div>
        <button
          className="pl-2 font-bold uppercase text-typography   hover:text-texthover  "
          onClick={handleMenuClick}
        >
          CLOSE MENU
        </button>
      </div>
      {/* Overlay */}
      {isMenuOpen && (
        <div
          className="z-60 fixed inset-0 bg-black bg-opacity-50"
          onClick={handleMenuClick}
        ></div>
      )}
    </div>
  )
}

export default NavigationBar
