"use client"
import React, { useState, useEffect, useRef } from "react"
interface AudioPlayerProps {
  src: string // Define the type for src here
}

const AudioPlayer: React.FC<AudioPlayerProps> = ({ src }) => {
  const audioRef = useRef(new Audio(src))
  const [isPlaying, setIsPlaying] = useState(false)
  const [progress, setProgress] = useState(0) // Progress bar state
  useEffect(() => {
    audioRef.current.src = src
  }, [src])

  const togglePlayPause = () => {
    const audio = audioRef.current
    if (isPlaying) {
      audio.pause()
      console.log(`Paused: ${src}`)
    } else {
      audio.play()
      console.log(`Playing: ${src}`)
    }
    setIsPlaying(!isPlaying)
  }
  // Update the progress as the audio plays
  const onPlaying = () => {
    const audio = audioRef.current
    setProgress((audio.currentTime / audio.duration) * 100)
  }

  // Seek the audio when the progress bar is clicked
  const onProgressClick = (e: any) => {
    const audio = audioRef.current
    const clickX = e.nativeEvent.offsetX
    const width = e.target.clientWidth
    const duration = audio.duration
    audio.currentTime = (clickX / width) * duration
  }
  useEffect(() => {
    const audio = audioRef.current
    audio.addEventListener("play", () => {
      setIsPlaying(true)
      console.log(`Playing: ${src}`)
    })
    audio.addEventListener("pause", () => {
      setIsPlaying(false)
      console.log(`Paused: ${src}`)
    })
    audio.addEventListener("timeupdate", onPlaying)

    return () => {
      audio.removeEventListener("play", () => {
        setIsPlaying(true)
        console.log(`Playing: ${src}`)
      })
      audio.removeEventListener("pause", () => {
        setIsPlaying(false)
        console.log(`Paused: ${src}`)
      })
      audio.removeEventListener("timeupdate", onPlaying)
    }
  }, [src])

  return (
    <div className="flex flex-col items-end">
      <div className="flex pb-3 pl-2 ">
        <button onClick={togglePlayPause} className="text focus:outline-none">
          {isPlaying ? (
            <svg
              xmlns="http://www.w3.org/2000/svg"
              height="20"
              viewBox="0 0 320 512"
              className="icon-color h-6 w-6"
            >
              <path d="M48 64C21.5 64 0 85.5 0 112V400c0 26.5 21.5 48 48 48H80c26.5 0 48-21.5 48-48V112c0-26.5-21.5-48-48-48H48zm192 0c-26.5 0-48 21.5-48 48V400c0 26.5 21.5 48 48 48h32c26.5 0 48-21.5 48-48V112c0-26.5-21.5-48-48-48H240z" />
            </svg>
          ) : (
            <svg
              xmlns="http://www.w3.org/2000/svg"
              height="20"
              viewBox="0 0 384 512"
              className="icon-color h-6 w-6"
            >
              <path d="M73 39c-14.8-9.1-33.4-9.4-48.5-.9S0 62.6 0 80V432c0 17.4 9.4 33.4 24.5 41.9s33.7 8.1 48.5-.9L361 297c14.3-8.7 23-24.2 23-41s-8.7-32.2-23-41L73 39z" />
            </svg>
          )}
        </button>
        {/* <div
          onClick={onProgressClick}
          className="w-full bg-gray-300 rounded-full h-1.5 cursor-pointer"
        >
          <div
            className="bg-yellow h-1.5 rounded-full"
            style={{ width: `${progress}%` }}
          ></div>
        </div> */}
      </div>
    </div>
  )
}

export default AudioPlayer
