import { type ClassValue, clsx } from "clsx"
import { twMerge } from "tailwind-merge"

export function cn(...inputs: ClassValue[]) {
  return twMerge(clsx(inputs))
}

// Helper functions
export const getDifficultyClass = (difficulty: number) => {
  if (difficulty === undefined || difficulty === null) {
    // Handle undefined or null difficulty
    // You can return a default class or handle the error as needed
    return "default-class" // Replace with an appropriate default class or error handling
  }

  switch (difficulty.toString()) {
    case "0":
      return "bg-basicbadgecolor" // Green for basic
    case "1":
      return "bg-advancebadgecolor" // Yellow for advance
    case "2":
      return "bg-expertbadgecolor" // Red for expert
    case "3":
      return "bg-masterbadgecolor " // Purple for master
    case "4":
      return "bg-[radial-gradient(ellipse_at_top_left,_var(--tw-gradient-stops))] from-black via-red to-black"
    case "5":
      return "bg-worldsendbadgecolor" // worlds end
    default:
      return "default-class" // Replace with an appropriate default class for unknown difficulty
  }
}

export const getGrade = (score: number) => {
  if (score >= 1009000) return "SSS+"
  if (score >= 1007500 && score <= 1008999) return "SSS"
  if (score >= 1005000 && score <= 1007499) return "SS+"
  if (score >= 1000000 && score <= 1004999) return "SS"
  if (score >= 990000 && score <= 999999) return "S+"
  if (score >= 975000 && score <= 990000) return "S"
  if (score >= 950000 && score <= 974999) return "AAA"
  if (score >= 925000 && score <= 949999) return "AA"
  if (score >= 900000 && score <= 924999) return "A"
  if (score >= 800000 && score <= 899999) return "BBB"
  if (score >= 700000 && score <= 799999) return "BB"
  if (score >= 600000 && score <= 699999) return "B"
  if (score >= 500000 && score <= 599999) return "C"
  if (score < 500000) return "D"
  return ""
}

export const getDifficultyText = (chartId: number) => {
  switch (chartId) {
    case 0:
      return "EASY" // Text for difficulty
    case 1:
      return "ADVANCE"
    case 2:
      return "EXPERT"
    case 3:
      return "MASTER"
    case 4:
      return "ULTIMA"
    case 5:
      return "WORLDS END"
  }
}

export const getRatingChangeColor = (ratingChange: string) => {
  switch (ratingChange) {
    case "Increase":
      return "text-ratingincrease" // Green for Increase
    case "Same":
      return "text-ratingsame" // Blue for Same
    case "Decrease":
      return "text-ratingdecrease" // Red for Decrease
    default:
      return "dark:text-gray" // Default color
  }
}

export interface JacketImageProps {
  jacketPath: string
}

export interface NavigationButtonsProps {
  currentPage: number
  totalPages: number
  onPageChange: (page: number) => void
  onNext: () => void
  onPrevious: () => void
}
